@@ -19,17 +19,24 @@ class DeviceLink : public QObject
     Q_OBJECT
 public:
     DeviceLink(const QString &deviceId, LinkProvider *parent);
-    ~DeviceLink() override = default;
 
     QString deviceId() const
     {
         return deviceInfo().id;
     }
 
+    int priority() const
+    {
+        return priorityFromProvider;
+    }
+
     virtual bool sendPacket(NetworkPacket &np) = 0;
 
     virtual DeviceInfo deviceInfo() const = 0;
 
+private:
+    int priorityFromProvider;
+
 Q_SIGNALS:
     void receivedPacket(const NetworkPacket &np);
 };
