@@ -15,8 +15,6 @@ MprisRemotePlayerMediaPlayer2::MprisRemotePlayerMediaPlayer2(MprisRemotePlayer *
 {
 }
 
-MprisRemotePlayerMediaPlayer2::~MprisRemotePlayerMediaPlayer2() = default;
-
 bool MprisRemotePlayerMediaPlayer2::CanQuit() const
 {
     return false;
@@ -60,3 +58,5 @@ QStringList MprisRemotePlayerMediaPlayer2::SupportedMimeTypes() const
 {
     return {};
 }
+
+#include "moc_mprisremoteplayermediaplayer2.cpp"
