@@ -4,8 +4,7 @@
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef PAUSEMUSICPLUGIN_H
-#define PAUSEMUSICPLUGIN_H
+#pragma once
 
 #include <QObject>
 #include <QSet>
@@ -20,14 +19,9 @@ class PauseMusicPlugin : public KdeConnectPlugin
 public:
     explicit PauseMusicPlugin(QObject *parent, const QVariantList &args);
 
-    bool receivePacket(const NetworkPacket &np) override;
-    void connected() override
-    {
-    }
+    void receivePacket(const NetworkPacket &np) override;
 
 private:
     QSet<QString> pausedSources;
     QSet<QString> mutedSinks;
 };
-
-#endif
