@@ -4,8 +4,7 @@
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef SFTPPLUGIN_MOUNTER_H
-#define SFTPPLUGIN_MOUNTER_H
+#pragma once
 
 #include <KJob>
 #include <KProcess>
@@ -26,6 +25,7 @@ public:
     {
         return m_started;
     }
+    void onPacketReceived(const NetworkPacket &np);
 
 Q_SIGNALS:
     void mounted();
@@ -33,7 +33,6 @@ Q_SIGNALS:
     void failed(const QString &message);
 
 private Q_SLOTS:
-    void onPackageReceived(const NetworkPacket &np);
     void onStarted();
     void onError(QProcess::ProcessError error);
     void onFinished(int exitCode, QProcess::ExitStatus exitStatus);
@@ -50,5 +49,3 @@ private:
     QString m_mountPoint;
     bool m_started;
 };
-
-#endif
