@@ -8,7 +8,8 @@
 
 MountLoop::MountLoop()
     : QEventLoop()
-{}
+{
+}
 
 bool MountLoop::exec(QEventLoop::ProcessEventsFlags flags)
 {
@@ -32,3 +33,5 @@ void MountLoop::exitWith(bool status)
     Q_EMIT result(status);
     exit(status ? 0 : 1);
 }
+
+#include "moc_mountloop.cpp"
